@@ -5,6 +5,7 @@ import yaml
 
 from data_pipelines_cli.cli_utils import (
     echo_error,
+    echo_warning,
     get_argument_or_environment_variable,
 )
 from data_pipelines_cli.io_utils import git_revision_hash
@@ -25,20 +26,27 @@ class DataPipelinesConfig(TypedDict):
     vars: Dict[str, str]
 
 
-def read_config_or_exit() -> DataPipelinesConfig:
+def read_config() -> Optional[DataPipelinesConfig]:
     # Avoiding a dependency loop between `cli_constants` and `data_structures`
     from data_pipelines_cli.cli_constants import CONFIGURATION_PATH
 
     if not CONFIGURATION_PATH.is_file():
-        echo_error(
+        echo_warning(
             "No configuration file found. Run 'dp init' to create it.",
         )
-        sys.exit(1)
+        return None
 
     with open(CONFIGURATION_PATH, "r") as f:
         return yaml.safe_load(f)
 
 
+def read_config_or_exit() -> DataPipelinesConfig:
+    config = read_config()
+    if not config:
+        sys.exit(1)
+    return config
+
+
 class DockerArgs:
     repository: str
     commit_sha: str
